## 0.9.5 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 0.9.4 (2021-11-26)

Add mypy error codes to '# type: ignore' comments (#6379)

## 0.9.3 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 0.9.2 (2021-10-11)

Fix return type of readComponents() (#6143)

